@@ -85,9 +85,9 @@ class PandasDoggo:
         """
 
         if boto_session:
-            self._s3_client = boto_session.client('s3')
+            self.s3_client = boto_session.client('s3')
         else:
-            self._s3_client = None
+            self.s3_client = None
 
     @staticmethod
     def _extract_file_format(path):
@@ -108,13 +108,6 @@ class PandasDoggo:
         if path.endswith('.gzip') or path.endswith('.gz'):
             return 'gzip'
 
-
-    @property
-    def s3_client(self):
-        if not self._s3_client:
-            self._s3_client = boto3.Session().client('s3')
-        return self._s3_client
-
     def load(self, path, file_format=None, compression=None, *args, **kwargs):
         """Load a file into a Pandas.DataFrame from local or s3 locations.
 
@@ -261,13 +254,11 @@ class FileDoggo:
     def close(self):
 
         if self._connection:
-            self._connection.close()
-
-        for c in self._to_close:
-            c.close()
+            for c in [self._connection] + self._to_close:
+                if not c.closed:
+                    c.close()
 
     def __enter__(self):
-
         return self.connection
 
     def __exit__(self, etype, value, traceback):
@@ -301,5 +292,8 @@ class FileDoggo:
 
     def _write_s3(self):
 
+        if self.compression == 'gzip':
+            self.connection.close() # flushes writing to gzip
+
         self.buffer.seek(0)
         self.client.upload_fileobj(Bucket=self.path.bucket, Key=self.path.key, Fileobj=self.buffer)
