@@ -227,6 +227,22 @@ class TestDoggos(unittest.TestCase):
         obj = s3.Object(pth.bucket, pth.key)
         obj.delete()
 
+    def test_write_csv_s3_gzip(self):
+        df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
+                                      4: 'l@gmail.com', 5: 'v@gmail.com', 6: None},
+                           'number': {0: 0, 1: 1, 2: 0, 3: 0, 4: 1, 5: 0, 6: 0}})
+        pth = S3Location('gd.dativa.test').join('generic', 'email_test_copy.csv.gz')
+
+        fh = PandasDoggo()
+
+        fh.save(df, pth, index=None, compression="gzip")
+
+        assert_frame_equal(fh.load_csv(pth), df)
+
+        s3 = boto3.resource('s3')
+        obj = s3.Object(pth.bucket, pth.key)
+        obj.delete()
+
     def test_read_pq_s3(self):
         fh = PandasDoggo()
 
